;******************************************************************************
;   This file is a basic template for creating relocatable assembly code for  *
;   a PIC18F252. Copy this file into your project directory and modify or     *
;   add to it as needed. Create a project with MPLINK as the language tool    *
;   for the hex file. Add this file and the 18F252.LKR file to the project.   *
;                                                                             *
;   The PIC18FXXX architecture allows two interrupt configurations. This      *
;   template code is written for priority interrupt levels and the IPEN bit   *
;   in the RCON register must be set to enable priority levels. If IPEN is    *
;   left in its default zero state, only the interrupt vector at 0x008 will   *
;   be used and the WREG_TEMP, BSR_TEMP and STATUS_TEMP variables will not    *
;   be needed.                                                                *
;                                                                             *
;   Refer to the MPASM User's Guide for additional information on the         *
;   features of the assembler and linker.                                     *
;                                                                             *
;   Refer to the PIC18FXX2 Data Sheet for additional information on the       *
;   architecture and instruction set.                                         *
;                                                                             *
;******************************************************************************
;                                                                             *
;    Filename:                                    *
;    Date:                                                                    *
;    File Version:                                                            *
;                                                                             *
;    Author:                                                                  *
;    Company:         KS 677B ;7f4f                                                *
;                                                                             * 
;******************************************************************************
;                                                                             *
;    Files required:         P18F252.INC                                      *
;                            18F252.LKR                                       *
;                                                                             *
;******************************************************************************

	LIST P=18F252, F=INHX32	;directive to define processor and file format
	#include <P18F252.INC>	;processor specific variable definitions

;******************************************************************************

;   Oscillator Selection:
;    CONFIG	OSC = HS_PLL_ON             ;LP
;Configuration
 ; CONFIG	OSC = HS
  CONFIG  OSC = HSPLL	
  CONFIG  OSCS = OFF
  CONFIG  PWRT = ON
  CONFIG  BOR = OFF;N 
  CONFIG  BORV = 42
  CONFIG  WDT = OFF;ON
  CONFIG  WDTPS = 64
  CONFIG  LVP = OFF
  CONFIG  CP0 = OFF,CP1 = OFF,CP2 = OFF,CPB = OFF
  CONFIG  CPD = OFF
  CONFIG	WRT0 = OFF,WRT1 = OFF,WRT2 = OFF,WRTB = OFF	
  CONFIG  WRTC = OFF,WRTD = OFF
  CONFIG  EBTR0 = OFF,EBTR1 = OFF,EBTR2 = OFF
;******************************************************************************
;Variable definitions
; These variables are only needed if low priority interrupts are used. 
; More variables may be needed to store other special function registers used
; in the interrupt routines.

		UDATA

WREG_TEMP	RES	1	;variable in RAM for context saving 
STATUS_TEMP	RES	1	;variable in RAM for context saving
BSR_TEMP	RES	1	;variable in RAM for context saving
FSR_TEMP	RES	1	;variable in RAM for context saving

		UDATA_ACS
FLAG            RES     1               ;
FLAG1           RES     1               ;
COM_Z           RES     1               ;
;------------------------------------
COU             RES     1               ;             2-10 
TEKH            RES     1               ;MEAZ
TEKL            RES     1               ;MEAZ
EDA             RES     1               ;MEAZ
DEA             RES     1               ;MEAZ   
COA             RES     1               ;MEAZ  
CCOI            RES     1               ;MEAZ
DCOI            RES     1               ;MEAZ           
COI             RES     1               ;MEAZ
DEI             RES     1               ;MEAZ
EDI             RES     1               ;MEAZ
TEMP            RES     1               ; 2-10
;-------------------------------------
NPR             RES     1               ;-PROGR OTOBR
NP1             RES     1               ; 
R1              RES     1               ;IND
R2              RES     1               ;IND
R3              RES     1               ;IND
R4              RES     1               ;IND
R5              RES     1               ;IND
R6              RES     1               ;IND
R7              RES     1               ;IND
R8              RES     1               ;IND
SL4             RES     1               ;IND
SL5             RES     1               ;IND
SL6             RES     1               ;SPEED
;------------------------------------
SL1             RES     1               ;OPROS
;------------------------------------
SLH             RES     1             ;      
SLL             RES     1               
;---------------------------------------
NL              RES     1               ;   
TNH             RES     1
TNL             RES     1               ;   
TNH1            RES     1               ;   
TNL1            RES     1               ;
Q_DT            RES     1               ;
;-----------------------------------   
DTH             RES     1               ;A   1  
DTL             RES     1
;-----------------------------------  
ZADV            RES     1               ;
;-----------------------------------
ZAD             RES     1               ;   
;----------------------------------- 
VDH             RES     1               ;  
VDL             RES     1
;---------------------------------
NSVDH           RES     1               ; 
NSVDL           RES     1               ;              
SVDH            RES     1               ; 
SVDL            RES     1               ;
;---------------------------------
SPWMH           RES     1               ;
SPWML           RES     1               ;
;---------------------------------
IDH_1           RES     1               ;
IDL_1           RES     1               ;  

IDL3            RES     1               ;Ĩ  
IDH3            RES     1               ;

TDH_1           RES     1               ;  
TDL_1           RES     1               ;  

DBC             RES     1               ;
DBB             RES     1               ;
DBA             RES     1               ;
;--------------------------------------
E0H             RES     1               ;
E0              RES     1               ;
E1H             RES     1               ;
E1              RES     1               ;
DIFH            RES     1               ;
DIF             RES     1               ;
PR0H            RES     1               ; 
PR0             RES     1               ;

Rkp             RES     1               ;
Rkd             RES     1               ;
Rki             RES     1               ;
Rko             RES     1               ;
INTH            RES     1               ;
INT             RES     1               ;
PWMH            RES     1               ;
PWM             RES     1               ;
;---------------------------------------------------------
Q1              RES     1               ;
SIST1           RES     1               ; . TMR3.  TNH,L
SIST1_1         RES     1               ; . TMR3.  TNH,L
SIST2           RES     1               ;
SIST3           RES     1               ;
SIST_STROB      RES     1               ;
SMEAZ           RES     1               ;
STROB2_S        RES     1               ;
;----------------------------------------------
TEMPA           RES     1               ;
TEMPB           RES     1               ;
TEMPC           RES     1               ;
TEMPH           RES     1               ;
TEMPL           RES     1               ;
;---------------------------------
TEMP1           RES     1               ;
TEMP2           RES     1               ;
CIKL            RES     1
RVH             RES     1
RVL             RES     1
TEMPV           RES     1				; Ȩ

;--------------------------------------------------------
accb0           RES     1      
accb1           RES     1 
accb2           RES     1      
accb3           RES     1
 
bccb0           RES     1 
bccb1           RES     1 ;   

temb0           RES     1
temb1           RES     1
temp            RES     1
temp0           RES     1
temp1           RES     1

loopcount       RES     1
;--------------------------------------------
BIT_AVR1        RES     1               ;  
BIT_AVR2        RES     1               ;  
BIT_AVR3        RES     1               ;  
SYM_AVR         RES     1                ;ר  
TEMP_AVR        RES     1                ;
SVDL_SB       	RES     1                ;
;-------------------------------------------------------- 
#define         PR_KN_AVR         FLAG,7; .   
#define         Favr              FLAG,6;
#define         PR_VPERED         FLAG,5;  Ш
#define         PR_HAZAD          FLAG,4;  
#define         PR_BLK            FLAG,3 
#define         PRDT1             FLAG,2 ; PA  1
#define         Fraz              FLAG,1
#define         Frab              FLAG,0 

#define         PR_IMP            FLAG1,7 
#define			PR_VIPOLN1		  FLAG1,6
#define         STROB_S           FLAG1,5 ; 
#define         PR_NOV            FLAG1,4 ;  Ȩ.
#define         PR_ZAD2           FLAG1,3; .  .  0.1 MS
#define         PR_VIPOLN         FLAG1,2; .  2- 
#define         PR_ZAD1           FLAG1,1; .  .  0.1 MS
#define         PR_MIN            FLAG1,0;  . .  





#define         FBEEP             PORTB,7 ;
#define         ABARIA            PORTB,5 

ANID            EQU     b'10000001'
ANTD            EQU     b'10001001'
ANBLK           EQU     b'10011001'
RESET_VECTOR	CODE	0x0000
				GOTO	INIT		;go to start of main code

;******************************************************************************
;High priority interrupt vector
; This code will start executing when a high priority interrupt occurs or
; when any interrupt occurs if interrupt priorities are not enabled.

HI_INT_VECTOR	CODE	0x0008
				BRA	HighInt		;go to high priority interrupt routine
;******************************************************************************
 
LOW_INT_VECTOR	CODE	0x0018
				BRA	LowInt		;go to low priority interrupt routine
;******************************************************************************

	CODE	0x002A 
;***************** *******************************************
HighInt
                BTFSC   INTCON,1
                GOTO    S1;         INT;ר   6-=0.5 
                BTFSC   INTCON3,0
                GOTO    S6;         ; INT1              
				RETFIE	FAST
;**************** *******************************************************
LowInt:
				MOVFF	STATUS,	STATUS_TEMP	;save STATUS register
				MOVFF	WREG,	WREG_TEMP		;save working register
				MOVFF	BSR,	BSR_TEMP		;save BSR register
;--------------------------------------------------------------------
                BTFSC   INTCON,2
                BRA    S2;         TMR0 ;	ר 
                BTFSC   PIR1,0
                BRA    S3;         TMR1 ;    
                BTFSC   PIR1,1
              	BRA    S4;         TMR2 ;     
                BTFSC   PIR2,1
             	BRA    S5;         TMR3 ;    ר 
             	BTFSC   INTCON3,1
                GOTO    S7;      ; INT2 
;-----------------------------------------------------------------------
MS7
				MOVFF	STATUS_TEMP,STATUS	;save STATUS register
				MOVFF	BSR_TEMP,BSR		;restore BSR register
				MOVFF	WREG_TEMP,WREG		;restore working register
				RETFIE
;******************************************************************************

;------------------------------------------------
S1
				MOVF	SIST_STROB,1,0
				BNZ		S12 
				MOVLW	.2;
				MOVWF    SIST_STROB	

                INCF    NL,1,0 ;   
            	MOVF    NL,0,0
             	SUBLW   .6
            	BTFSS   STATUS,Z     
                GOTO    S11
;-------------Tn =  -----------         

S13 
                MOVFF   TMR3L,TNL1; 
                MOVFF   TMR3H,TNH1;
    			CLRF	NL,0
				CLRF	TMR3H,0				
				CLRF	TMR3L,0
				BTFSS	PR_MIN,0
				BRA		S11
				MOVLW	0XFF
				MOVWF	TNH1,0	
				MOVWF	TNL1,0

S11
				BCF		PR_MIN,0
S12
      
                BCF     INTCON,1                
				RETFIE	FAST
;-----------------------------------------------------------
 


;---------------- 0-T-8 MKSEK-----0.1048-------------
S2
               BCF     INTCON,2    
;------------------1---------------------------------
               MOVF    TEMP1,1,0;    ZAD=2 SEK
               BTFSC   STATUS,Z
               GOTO    S21
               DECF    TEMP1,1,0
               BTFSC   STATUS,Z,0                
               BCF     PR_ZAD1,0
S21
;------------------2---------------------------------
               MOVF    TEMP2,1,0; ZAD=X,X SEK
               BTFSC   STATUS,Z
               GOTO    S22
               DECF    TEMP2,1,0
               BTFSC   STATUS,Z,0                
               BCF     PR_ZAD2,0
               BTFSC   STATUS,Z,0                
               BCF     FBEEP,0
;------------------------------------------------------------
S22 
              INCF    SIST2,1,0 ;
               MOVF    SIST2,0,0
               SUBLW   .4
               BTFSS   STATUS,Z
               GOTO S23
               CLRF    SIST2,0
;-------------------------------------
               MOVF    NSVDH,0,0
               MOVWF   SVDH,0
               MOVF    NSVDL,0,0
               MOVWF   SVDL,0
               CLRF    NSVDH,0
               CLRF    NSVDL,0
;-------------------------------------------

				BTFSC 	 PORTA,5,0
				BRA 	 S23
				BCF	 	 STATUS,C,0
				RRCF	 SVDH,1,0
				RRCF	 SVDL,1,0
;----------------  ----------------
S23

;------   ---------
;------       ----
			MOVLW	.3
			SUBWF	IDH_1,0,0
      		BTFSC	STATUS,C,0
    	    GOTO	PWM5
;------------------------------------------- 
            movf	IDH_1, 0,0		
    		subwf	SPWMH, 0,0
    		movwf	TEMP_AVR,0
       		movf	IDL_1, 0,0		
    		subwf	SPWML, 0,0
       		btfss	STATUS,C,0
    		DECF	TEMP_AVR,1,0

    		BTFSS	TEMP_AVR,7,0
			GOTO	PWM1; 
    	    GOTO	PWM2
;------------------------------------
PWM1
			BCF		STATUS,C,0
			GOTO	PWM3
PWM2		
			BSF		STATUS,C,0
PWM3
			RRCF		BIT_AVR1,1,0
			RRCF		BIT_AVR2,1,0
			RRCF		BIT_AVR3,1,0

			CLRF	SYM_AVR,0
PWM6
			BTFSC	BIT_AVR1,7,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR1,6,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR1,5,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR1,4,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR1,3,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR1,2,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR1,1,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR1,0,0
			INCF	SYM_AVR,1,0

			BTFSC	BIT_AVR2,7,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR2,6,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR2,5,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR2,4,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR2,3,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR2,2,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR2,1,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR2,0,0
			INCF	SYM_AVR,1,0

			BTFSC	BIT_AVR3,7,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR3,6,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR3,5,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR3,4,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR3,3,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR3,2,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR3,1,0
			INCF	SYM_AVR,1,0
			BTFSC	BIT_AVR3,0,0
			INCF	SYM_AVR,1,0
            GOTO    MS7			
;----     ---
PWM5
			MOVLW	.20
			MOVWF	SYM_AVR
;------------------------------------------
            GOTO    MS7
;----------------------------------------------------------
;-------------- 1- -----------------------
S3
                BTFSS   PRDT1
                GOTO    S31
   				BTFSC   PR_KN_AVR
                GOTO    S31        
                BSF     PORTB,4,0
  				CALL    ZAD10       
                BCF     PORTB,4,0;
S31
                BCF     PIR1,0
                GOTO    MS7
;-------------- 2----0,08 MS-----   -------
S4

                BCF     PIR1,1
;-------------------------------------------
				MOVF	SIST_STROB,1,0
				BZ		S41
				BTFSS	PORTB,0,0
				BRA		S42				
				NOP
				NOP
				NOP
				NOP
				NOP
				NOP
				BTFSC	PORTB,0,0
				BRA		S41
S42
				DECF	SIST_STROB,1,0
;------------------------------------------------
S41
				MOVF	STROB2_S,1,0
				BZ		S43

 				DCFSNZ	STROB2_S,1,0
				BCF 	STROB_S,0
S43
                GOTO     MS7
;---------------------------------------------------------------           
;-------------- 3---50MS-------------
;-----    --------------
S5
			   BSF	    PR_MIN,0
			   MOVLW    0XFD
			   CPFSGT	SIST1,0	
			   INCF	    SIST1,1,0	
               BCF      PIR2,1
               GOTO     MS7             

;--------------Ȩ  INT1-------------------------------------
S6
                INCF    NSVDL,1
                BTFSC   STATUS,2
                INCF    NSVDH,1
                BCF     INTCON3,0,0               
               	RETFIE	FAST
;--------------Ȩ   INT2-------------------------------------
S7
                BCF     INTCON3,1,0 ;
				BTFSC 	STROB_S,0 
                GOTO    MS7

 				BSF 	STROB_S,0
				MOVLW	.100
				MOVWF	STROB2_S,0

;-----------------ZAGRYZKA--------------------
                 MOVF    DTH,0,0
                 MOVWF   TMR1H,0
                 MOVF    DTL,0,0
                 MOVWF   TMR1L,0


				BTFSC	 PR_ZAD1,0;  2-  
				BRA		S72
	            MOVFF    TNH1, TNH
	            MOVFF    TNL1, TNL
 				BRA		S71
S72
				MOVLW	0XFF
	            MOVWF   TNH,0
	            MOVWF   TNL,0


S71
				MOVF    SIST1,1,0
				BTFSC	STATUS,Z,0
				BRA		S73
				BTFSS	PR_MIN
				DECF	SIST1,1,0

S73
;         		INCF    Q_DT,1,0;   
 ;       	 	MOVF    Q_DT,0
 ;        		SUBLW   .4
 ;       		BTFSS   STATUS,2       
;				BRA		S74
;				CLRF	Q_DT

				BSF	 	 PR_NOV
;S74
                GOTO    MS7


;??????????????????????????????????????????????????????????????
;??????????????????????????????????????????????????????????????
;??????????????????????????????????????????????????????????????

INIT
        
             MOVLW       b'11111111'         
             MOVWF       TRISA,0
                    
             MOVLW       b'00001111';
             MOVWF       TRISB,0
                     
             MOVLW       b'00100001';
             MOVWF       TRISC,0
;-------------------TMR0--------------------                    
             MOVLW       b'10000011'; 1:16 16
             MOVWF       T0CON,0


;-------------------TMR1--------------------                                               
 
             MOVLW       b'10010001'; 1:2
             MOVWF       T1CON,0

 
;-------------------TMR2--------------------  
             MOVLW       b'00000111';1/16
             MOVWF       T2CON,0

             MOVLW       .50;
             MOVWF       PR2,0
;-------------------TMR3--------------------
             MOVLW       b'10110001'; 1:8
             MOVWF       T3CON,0 

;-------------------------------------------
             MOVLW       b'11110000';b'11110000'
             MOVWF       INTCON,0                  ;!!!!!INT!!!!!!!!!!!!!

             MOVLW       b'00110000';    INT0.
             MOVWF       INTCON2,0
                  
             MOVLW       b'01011000';b'00011000
             MOVWF       INTCON3,0                  


             MOVLW       b'00000011';----PERIPHERAL------TMR1
             MOVWF       PIE1,0

             MOVLW        b'00000010'
             MOVWF        PIE2,0

             MOVLW        b'10000000';
             MOVWF        IPR1,0

            MOVLW        b'00000000'
             MOVWF        IPR2,0

             MOVLW        b'10000000'
             MOVWF        RCON,0

 
;------------------SPI----------------------------------                                     
              MOVLW       b'00000000'
             MOVWF       SSPCON1,0      ;SPI
;-------------------ADC---------------------------------                     
    
             MOVLW       b'10000001'     
             MOVWF       ADCON0,0
                     
             MOVLW       b'11000100';    
             MOVWF       ADCON1,0
;-------------------------------------------------------  
				 CLRF    BSR  
                 CLRF    FLAG,0  
                 CLRF    FLAG1,0  
                 CLRF    SVDH,0  
                 CLRF    SVDL,0 
                 CLRF    SPWMH,0  
                 CLRF    SPWML,0
                 CLRF    SIST2,0
				 CLRF 	 Q_DT     
                 CLRF    DBC,0
                 MOVF    DBC,0,0
                 MOVWF   PORTC,0
                 CLRF    DBB,0
                 MOVF    DBB,0,0
                 MOVWF   PORTB,0   
                 BSF     Fraz,0; 
         		CLRF     Q_DT,0
	            CLRF	 SVDH,0
				CLRF	 SVDL,0

	            MOVLW    0X01
				MOVWF	 SPWMH,0
	            MOVLW    0X90
				MOVWF	 SPWML,0	               

;---     - 
				BSF		FBEEP,0
                MOVLW   .5;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
M5_1
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		M5_1

;------------------------------------------------------------------
M4
				BSF		FBEEP,0
                MOVLW   .1;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
M5
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		M5
                MOVLW   .1;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0
M6
				NOP
 		        CLRWDT				
				BTFSC	PR_ZAD2,0	
				BRA		M6
  
        		BTFSS   PORTA, 4,0;
        		BSF		PORTB,5
        		BTFSS   PORTA, 4,0;

        		GOTO    M4
        		BCF		PORTB,5
;--------------------------------------------------------------------
M41
				BSF		FBEEP,0
                MOVLW   .2;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
M51
				NOP
 		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		M51
                MOVLW   .2;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0
M61
				NOP
 		        CLRWDT				
				BTFSC	PR_ZAD2,0	
				BRA		M61
  
        		BTFSS   PORTA, 2,0;
        		BSF		PORTB,5
        		BTFSS   PORTA, 2,0;
        		GOTO    M41
        		BCF		PORTB,5

;--------------------------------------------------------------------
M42
				BSF		FBEEP,0
                MOVLW   .3;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
M52
				NOP
 		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		M52
                MOVLW   .3;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0
M62
				NOP
 		        CLRWDT				
				BTFSC	PR_ZAD2,0	
				BRA		M62
  
        		BTFSC   PORTC, 0,0;
        		BSF		PORTB,5
        		BTFSC   PORTC, 0,0;
        		GOTO    M42
        		BCF		PORTB,5


							
;---------------------------------
				BCF		FBEEP
 		          CLRWDT
;---------------------------------------------------                 
                 CALL    DT11,0 ;   
                 CALL    DLDV1,0;       
 ;***************************************************************************************************
M1
 		         
                 CALL    PWA,0
                 CALL    C0NST_DV,0
                 CALL    ANALIZ_R,0
                 CALL    ANALIZ_S,0
        		 CALL    VIVOD,0
				 BTFSS	 PR_NOV,0
          	     BRA M1
                 CALL    SPEED,0
                 CALL    DATA_DT,0
                 CALL    DATA_POD,0
                 CALL    ID,0
          	     BRA M1


;****************************************
ANALIZ_R


				MOVF	PORTC,0,0
				MOVWF	DBC,0
				BTFSC 	DBC,0,0
				BRA	ANZ1

				BTFSS 	PORTA,2,0;Ш
				BRA	ANZ2

				BTFSS 	PORTA,4,0;
				BRA	ANZ3

ANZ4
				BCF 	PRDT1,0
				BCF		Frab,0 
				BSF		Fraz,0 
				BCF		Favr,0 
				CALL	DT11
				BCF		PORTB,5,0  ; 
				BCF		PRDT1,0  ;   
				BCF		DBC,4,0;    
				BCF		DBC,3,0;    
        		MOVF	DBC,0,0
				MOVWF	PORTC,0				
				BCF		PR_VIPOLN,0; 2- 
				BCF		PR_VIPOLN1; 3- , 1-2	
				BCF		PR_BLK,0   ; 
				BCF		FBEEP,0   ;
				BCF		PR_KN_AVR,0

;-----------  -----------------------
				MOVLW	.20 
				MOVWF	TEMP1,0 
				BSF 	PR_ZAD1,0 
;-------------------------------------
				MOVLW	0X7D
				MOVWF	SIST1,0
 				BTFSC     PR_VPERED,0
				BRA		ANZ12	
 				BTFSC		PR_HAZAD,0
				BRA		ANZ12
 				RETURN	
;---------  -----------    
ANZ12
				MOVLW	.20 
				MOVWF	TEMP2,0 
				BSF 	PR_ZAD2,0 

ANZ13
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		ANZ13

				BCF     PR_VPERED,0
 				BCF		PR_HAZAD,0 
  
				RETURN				         		        		

;--------------- Ш-------------------
ANZ2 
				BTFSC 	PR_KN_AVR,0
				RETURN   
				BTFSC 	PR_BLK,0
				RETURN   
				BTFSC 	Favr,0 
				RETURN
				BTFSC 	PR_HAZAD,0 
				BRA 	ANZ4;
;------ SV=100 /  Ѩ     1- .----    
                MOVF	SVDH, 1,0 		
                BTFSS   STATUS,Z,0
                BRA		ANZ10

            	MOVF	SVDL, 0		
        		SUBLW	.10
                BTFSC   STATUS,C,0 
                BRA		ANZ4
;-----------------------------------


ANZ10
				BTFSC	DBC,4,0
				BRA		ANZ102

				BSF		DBC,4,0;  
        		MOVF	DBC,0,0
				MOVWF	PORTC,0	
				BSF		FBEEP,0
                MOVLW   .2;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
ANZ101
				NOP
 		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		ANZ101

ANZ102
 
				BSF     PR_VPERED,0         
        	    BSF     Frab,0  ;   Ш 
                BSF     PRDT1,0 ;    
        		RETURN  

;--------------- -------------------
ANZ3
				BTFSC 	PR_KN_AVR,0
				RETURN   
				BTFSC 	PR_BLK,0
				RETURN   
				BTFSC 	Favr,0 
				RETURN
				BTFSC 	PR_VPERED,0 
				BRA 	ANZ4;
;------ V=100 /  Ѩ     1- .-----    
                MOVF	SVDH, 1,0 		
                BTFSS   STATUS,Z,0 
                BRA		ANZ11
            	MOVF	SVDL, 0		
        		SUBLW	.10
                BTFSC   STATUS,C,0 
                BRA		ANZ4
;-----------------------------------------
ANZ11
 				BSF		PR_HAZAD,0

				BTFSC	PORTC,3,0
				BRA		ANZ112

				BSF		DBC,3,0;  
        		MOVF	DBC,0,0
				MOVWF	PORTC,0	
 				BSF		FBEEP,0
                MOVLW   .2;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
ANZ111
				NOP
 		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		ANZ111
ANZ112 
;-------------------------------------------------------------------
				BTFSC	DBC,4,0
				BRA		ANZ113

				BSF		DBC,4,0;  
        		MOVF	DBC,0,0
				MOVWF	PORTC,0	

                MOVLW   .2;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
ANZ114
				NOP
 		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		ANZ114
ANZ113 

        	    BSF     Frab,0  ;   
                BSF     PRDT1,0 ;    
        		RETURN  
;--------------   . ----------------------------
ANZ1
        	    BCF   Frab,0 ;  
        		BSF   Favr,0 
				BSF		PR_KN_AVR,0
				BCF		PRDT1,0  ;   
				BCF		PORTC,4,0;    
				BCF		PORTC,3,0;    	
				BSF		PORTB,5,0  ; 
        		RETURN 

;----------------------------------------           
ANALIZ_S
            	MOVF	VDH, 1,0 
	        	BTFSS	STATUS,Z,0 
            	RETURN	        	     			 
            	movf	VDL, 0,0 		; 
 	        	SUBLW	.15     	    
	        	BTFSS	STATUS,C,0 
            	RETURN
;-----------------------------------------
				BTFSS	Frab,0 ; ,   
				RETURN		;     100 /
	            BTFSC   Fraz,0
		        RETURN
                CALL    DT11
			    BSF     Favr,0 
                BCF     Frab,0 
                BCF    PRDT1,0; 

                BCF    	DBC, 3,0;  	                 
 				BCF		DBC,4,0;  
        		MOVF	DBC,0,0
				MOVWF	PORTC,0	

        		BSF		PORTB,5,0
 
				BTFSC		PR_VIPOLN1; 3- , 1-2
				RETURN
;---------------------1---------------------------
				BSF		PR_VIPOLN1; 3- , 1-2					
				BSF		FBEEP
                MOVLW   .3;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
AN_S1
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		AN_S1
 				BCF		FBEEP,0

                MOVLW   .3;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
AN_S2
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		AN_S2
 				BCF		FBEEP,0
;---------------------2-----------------------------
				BSF		FBEEP
                MOVLW   .3;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
AN_S3
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		AN_S3
 				BCF		FBEEP,0

                MOVLW   .3;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
AN_S4
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		AN_S4
;------------------------3--------------------------
				BSF		FBEEP
                MOVLW   .3;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
AN_S5
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		AN_S5
 				BCF		FBEEP,0
            	RETURN
;---------------------------------------------------

;-------AN1-ID-------------
ID
				

		        MOVLW   ANID    ; . .+
		        MOVWF   ADCON0,0
		        CALL    ZAD20
		        BSF     ADCON0,GO
ID1
				BTFSC	ADCON0,GO
				GOTO	ID1
		        MOVFF   ADRESH,IDH_1
		        MOVFF   ADRESL,IDL_1

				
TD
		        MOVLW	ANTD
		        MOVWF   ADCON0,0
		        CALL    ZAD20
		        BSF     ADCON0,GO
TD1
				BTFSC	ADCON0,GO
				GOTO	TD1
		        MOVFF   ADRESH,TDH_1
		    	MOVFF   ADRESL,TDL_1

				BTFSS	Frab,0 ; ,  T=630 =80  
				BCF		FBEEP
				BTFSS	Frab,0 ; ,  T=630 =80  
				RETURN
TD2
            	MOVLW	0X02
				SUBWF	TDH_1, 0,0
				MOVWF	R8,0

            	MOVLW	0X76
				SUBWF	TDL_1, 0,0
    			MOVWF	R7,0
				BTFSS	STATUS,C,0
				DECF	R8,1,0
		
		        BTFSC   R8,7,0
				BSF		FBEEP
;---------------------------------------------------

            	MOVLW      b'11000110';   .     
            	MOVWF       ADCON1,0


				MOVF	PORTC,0,0
				MOVWF	DBC,0
				BTFSS 	DBC,3,0
				BRA		BL1

			 	BTFSS	PORTA,2,0
				BSF		PR_BLK,0;    
			 	BTFSS	PORTA,4,0
				BSF		PR_BLK,0;    
BL1
             	MOVLW       b'11000100';b'11000110'     
             	MOVWF       ADCON1,0

				BTFSS		PR_BLK,0;  ,    
				RETURN	
				BSF		Favr
                BSF    PORTB, 5,0	;  
                BCF     PRDT1,0	; 

                BCF    	DBC, 3,0;  	                 
 				BCF		DBC,4,0;  
        		MOVF	DBC,0,0
				MOVWF	PORTC,0	
  ;				RETURN
;------------   ר  Ш-------------
;BL_BEEP
				BTFSS		PR_BLK,0;  ,    
				RETURN
				BTFSC		PR_VIPOLN; 2- , 1-2
				RETURN	

 				BSF		FBEEP,0

                MOVLW   .3;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
BL3
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		BL3
 				BCF		FBEEP,0

                MOVLW   .4;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
BL4
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		BL4
				BSF		FBEEP,0
                MOVLW   .8;   ZAD=0.3 SEK
                MOVWF   TEMP2,0;
                BSF     PR_ZAD2,0 
BL5
				NOP
		        CLRWDT
				BTFSC	PR_ZAD2,0	
				BRA		BL5
				BCF		FBEEP,0
				BSF		PR_VIPOLN; 2- , 1-2
				RETURN

;--------------------------------------------------------
SPEED
;-----------------------------------------------------
;  INPUT:   accb0,accb1,accb2,accb3 / bccb0,bccb1  (H,L)
;  UZE :    temb0,temb1,temp
;  REZALT:  accb0,accb1,accb2,accb3.temp0,temp1 (lsb)
;           ( bccb1,bccb0 = const ) temp0,temp1=???
;----------------------------------------------
;N/10=750*4/TH3,TL3. CONST=0X 16 E3 60  6
				CLRF	accb0,0	
				MOVLW	0X16
				MOVWF	accb1,0					
				MOVLW	0XE3
				MOVWF	accb2,0					
				MOVLW	0X60
				MOVWF	accb3,0

;------------    SIST1--------------				
				MOVF	SIST1,0,0
				MOVWF	SIST1_1,0
				ANDLW	0XFC
				MOVWF	SIST1_1,0
				MOVF    SIST1_1,1,0
				BTFSC	STATUS,Z,0
				GOTO	SPEEDL1
				CLRF	VDH;,0
				CLRF	VDL,0
				RETURN
;---------------  ---------------------------					
SPEEDL1
				MOVF	TNH,1,0
				BTFSS	STATUS,Z,0
				BRA		SPEEDL2
				MOVF	TNL,1,0
				BTFSS	STATUS,Z,0
				BRA		SPEEDL2
				CLRF	VDH,0
				CLRF	VDL,0
				RETURN
SPEEDL2
				MOVFF	TNH,bccb0
				MOVFF	TNL,bccb1	
				CALL	DIV1
				MOVFF	accb2, VDH
				MOVFF	accb3, VDL
				RETURN
;****************************************
;------------;  XX /--------------------------------
DATA_DT
			BCF		PR_NOV,0
 ;-----------------------------------------------------
             BTFSS   Frab,0
             CALL    DT11
             BTFSS   Frab,0
             RETURN            
;-----------------------------------------------------
             BTFSC   Favr,0
             GOTO    DT11
;-----------------------------------------------------
YYY
       	   	CALL    Ferr
	      	CALL    Ppp  		
       		CALL    DifCom 
       		CALL    IntCom
       		CALL    Total
       		CALL    DATA_POD
        	RETURN
;-----------------  ------------------------------------
Ferr
                 BTFSC     PR_ZAD1;   
 				 BRA	FER2
				 MOVF	VDH, 0,0;		
				 SUBWF	SVDH, 0,0
				 MOVWF	E0H,0
		
				 MOVF	VDL, 0,0	;	
				 SUBWF	SVDL, 0,0
				 MOVWF	E0,0
				 BTFSS	STATUS,C,0
				 DECF	E0H,1,0
		
		         BTFSS   E0H,7,0
				 BRA	FER1
		         BCF	Fraz,0

				 RETURN
FER1
	             BTFSS   Fraz,0
		         RETURN
;-----------------------------------------
FER2
	        	 MOVLW	.4
	        	 movwf	E0,0
	        	 CLRF    E0H,0
	        	 RETURN
;-----------------------------------------------------

Ppp							; ..
				MOVF	E0,   0,0	; E0 x KP = PR0H:PR0
				MOVWF	PR0,  0		
				MOVF	E0H,  0,0
				MOVWF	PR0H, 0
	
				MOVF	Rkp , 0,0
				MOVWF	TEMPA,0
PP1	
				BCF		STATUS,C,0
				RLCF	PR0,  1,0
				RLCF	PR0H, 1,0
				DECFSZ	TEMPA,1,0
				BRA		PP1
				RETURN

;------------------------------------------------------

DifCom						; 
				MOVF	E1H, 0,0	; DIFH:DIF=(E0H:E0-E1H:E1)*KD(=8)
				SUBWF	E0H, 0,0		
				MOVWF	DIFH,0
				MOVF	E1, 0,0
				SUBWF	E0, 0,0
				MOVWF	DIF,0
				BTFSS	STATUS,C,0
				DECF	DIFH, 1,0
	
				MOVF	Rkd ,0,0
				MOVWF	TEMPA,0
DIF1	
				BCF		STATUS,C,0
				RLCF		DIF, 1,0
				RLCF		DIFH, 1,0
				DECFSZ	TEMPA,1,0
				BRA		DIF1
	
				MOVF	E0H, 0,0
				MOVWF	E1H,0
				MOVF	E0, 0,0
				MOVWF	E1,0
				RETURN

;------------------------------------------------------

IntCom					; 
				MOVF	E0H, 0,0		
				MOVWF	TEMPB,0	;INTH:INT=INTH:INT+E0H:E0*KI(=8)
				MOVF	E0, 0,0
				MOVWF	TEMPA,0
	
				MOVF	Rki ,0,0
				MOVWF	TEMPC,0		;E0*KI
	
				MOVF	TEMPC, 1,0	;  Ki=0
				BTFSC	STATUS,Z,0	
				GOTO	INT11		;  
INT12	
				BCF		STATUS,C,0
				RLCF		TEMPA, F,0
				RLCF		TEMPB, F,0
				DECFSZ	TEMPC,1,0
				BRA		INT12
INT11
				MOVF	TEMPA, W,0
				ADDWF	INT, F,0
				BTFSC	STATUS,C,0
				INCF	INTH, F,0
	
				MOVF	TEMPB, W,0
				ADDWF	INTH, F,0
				RETURN

;-------------------------------------------------------
Total	; PWMH:PWM=INTH:INT+PR0H:PR0+DIFH:DIF
PCOM
				MOVF	PR0H, W,0		; +PR0H:PR0
				MOVWF	PWMH,0
				MOVF	PR0, W,0	
				MOVWF	PWM,0
ICOM
				MOVF	INTH, 0	,0	; +INTH:INT
				ADDWF	PWMH, 1,0
				MOVF	INT, 0,0	
				ADDWF	PWM, 1,0
				BTFSC	STATUS,C,0
				INCF	PWMH, 1,0
DCOM
				MOVF	DIFH, W,0		; +DIFH:DIF
				ADDWF	PWMH, F,0
				MOVF	DIF, W,0	
				ADDWF	PWM, F,0
				BTFSC	STATUS,C,0
				INCF	PWMH, F,0
	;-------------------------------------
				BTFSC	PWMH,7;  PWMH  
				BRA 	NegPwm
				MOVF	PWMH,0,0	
				ADDLW	0X8B;=FF-8B= ~ 30000
				BTFSS	STATUS,C,0
				RETURN


				MOVLW	0X69
				MOVWF	PWMH,0
				MOVWF	INTH,0
				MOVLW	0X78
				MOVWF	PWM,0
				MOVWF	INT,0

				RETURN
NegPwm
				CLRF	PWMH,0
				CLRF	PWM,0
				CLRF	PWM,0
				CLRF    INTH,0
				CLRF    INT,0
				CLRF	PWM,0
				RETURN
;-------------------------------------------------------

DATA_POD
;-----------   -----------        
       ;   
       ;10 = 50.000 =
	  ;   20000 
       
;				MOVLW	0X23
;				MOVWF	PWMH,0

;				MOVLW	0X28
;				MOVWF	PWM,0
    
 
            CLRF   SLH ,0         
            CLRF   SLL ,0       
;--------------------------
            MOVLW   0X38
            ADDWF   PWM,0,0
            MOVWF   SLL,0                 
        	BTFSC	STATUS,C,0  
            INCF    SLH,1,0   
            MOVLW   0X4A   ;C
            ADDWF   PWMH,0,0
            MOVWF   SLH ,0                   

           MOVF    SLH,0,0;ZAGRYZKA 1
           MOVWF   DTH,0 
           MOVF    SLL,0,0
           MOVWF   DTL,0
           RETURN
;-----------------------------------------------
PWA
			MOVF	SYM_AVR,0
			ADDLW	.245			
			BTFSS	STATUS,C
            RETURN		
;----    ---

			BSF     Favr;
            BCF     PRDT1,0        		
       		CALL    DT11
            BSF    PORTB, 5,0	;  
            BCF     PRDT1,0	; 
            BCF    PORTB,2,0	; 
			MOVLW	0X7D	
			MOVWF	SIST1,0
            RETURN

;*****************************************
OPROSKN

;---------   --


                 BTFSC   NP1,7,0
                 GOTO    OPN7
                 BTFSC   NP1,6,0
                 GOTO    OPN6
                 BTFSC   NP1,5,0
                 GOTO    OPN5
                 BTFSC   NP1,4,0
                 GOTO    OPN4
                 BTFSC   NP1,3,0
                 GOTO    OPN3


                 BTFSC   NP1,2,0
                 GOTO    OPN2
                 BTFSC   NP1,1,0
                 GOTO    OPN1
                 BTFSC   NP1,0,0
                 GOTO    OPN0
                 GOTO    OPN20
;------------------------
OPN0
                 CLRF    NPR,0
                 GOTO    OPN20
;-----------------------
OPN1
                 MOVLW   .1
                 MOVWF   NPR,0
                 GOTO    OPN20                           
;-----------------------
OPN2
                 MOVLW   .2
                 MOVWF   NPR,0
                 GOTO    OPN20
;-----------------------
OPN3
                 MOVLW   .3
                 MOVWF   NPR,0
                 GOTO    OPN20                           
;-----------------------
OPN4
                 MOVLW   .4
                 MOVWF   NPR,0
                 GOTO    OPN20           
;-----------------------
OPN5
                 MOVLW   .5
                 MOVWF   NPR,0
                 GOTO    OPN20                           
;-----------------------
OPN6
                 MOVLW   .6
                 MOVWF   NPR,0
                 GOTO    OPN20
;-----------------------
OPN7
                 MOVLW   .7
                 MOVWF   NPR,0
                 GOTO    OPN20                           
;-----------------------
 
OPN20
 
 
                 MOVF    NPR,0,0
                 SUBLW   .0

                 BTFSC   STATUS,2,0
                 GOTO    DB0
                 MOVF    NPR,0
                 SUBLW   .1
                 BTFSC   STATUS,2,0
                 GOTO    DB1
                 MOVF    NPR,0,0
                 SUBLW   .2
                 BTFSC   STATUS,2,0
                 GOTO    DB2
                 MOVF    NPR,0,0
                 SUBLW   .3
                 BTFSC   STATUS,2,0
                 GOTO    DB3
                 MOVF    NPR,0,0
                 SUBLW   .4
                 BTFSC   STATUS,2,0
                 GOTO    DB4
                 MOVF    NPR,0,0
                 SUBLW   .5
                 BTFSC   STATUS,2,0
                 GOTO    DB5
                 MOVF    NPR,0,0
                 SUBLW   .6
                 BTFSC   STATUS,2,0
                 GOTO    DB6
                 MOVF    NPR,0,0
                 SUBLW   .7
                 BTFSC   STATUS,2,0
                 GOTO    DB7
                 GOTO    DB0
                 RETURN       
 
;--------- DB-0 ----------------------------
;---   -------------
;-- --   8888-888---------------------
DB0

                    
                 BTFSC   FLAG,7,0 
                 MOVLW      .1
                 BTFSC   FLAG,7,0 
                 MOVWF   R8,0                
                 BTFSS  FLAG,7,0 
                 MOVLW      .0
                 BTFSS   FLAG,7,0 
                 MOVWF   R8,0                   
                 
                 
                 BTFSC   FLAG,6,0 
                 MOVLW      .1
                 BTFSC   FLAG,6,0 
                 MOVWF   R7 ,0               
                 BTFSS  FLAG,6,0 
                 MOVLW      .0
                 BTFSS   FLAG,6,0 
                 MOVWF   R7,0                     
                 
                  BTFSC   FLAG,5 ,0
                 MOVLW      .1
                 BTFSC   FLAG,5,0 
                 MOVWF   R6,0                
                 BTFSS  FLAG,5,0 
                 MOVLW      .0
                 BTFSS   FLAG,5,0 
                 MOVWF   R6,0                     
                 
                  BTFSC   FLAG,4,0 
                 MOVLW      .1
                 BTFSC   FLAG,4,0 
                 MOVWF   R5,0                
                 BTFSS  FLAG,4,0 
                 MOVLW      .0
                 BTFSS   FLAG,4,0 
                 MOVWF   R5                     
                 
                   BTFSC   FLAG,3,0 
                 MOVLW      .1
                 BTFSC   FLAG,3,0 
                 MOVWF   R4,0                
                 BTFSS  FLAG,3,0 
                 MOVLW      .0
                 BTFSS   FLAG,3,0 
                 MOVWF   R4,0                    
                 
                   BTFSC   FLAG,2,0 
                 MOVLW      .1
                 BTFSC   FLAG,2,0
                 MOVWF   R3,0                
                 BTFSS  FLAG,2,0 
                 MOVLW      .0
                 BTFSS   FLAG,2,0 
                 MOVWF   R3,0                    
                 
                  BTFSC   FLAG,1,0 
                 MOVLW      .1
                 BTFSC   FLAG,1,0 
                 MOVWF   R2 ,0               
                 BTFSS  FLAG,1,0 
                 MOVLW      .0
                 BTFSS   FLAG,1,0 
                 MOVWF   R2,0                     
                 
                 BTFSC   FLAG,0,0 
                 MOVLW      .1
                 BTFSC   FLAG,0,0 
                 MOVWF   R1,0                
                 BTFSS  FLAG,0,0 
                 MOVLW      .0
                 BTFSS   FLAG,0,0 
                 MOVWF   R1     
                 RETURN

 ;--------- DB-1 ------------------------------------
;---    ----- 
;--        --   1888#8888 ---------------------
DB1 
                 MOVF    VDH,0,	0
                 MOVWF   TEKH,	0
                 MOVF    VDL,0,	0
                 MOVWF   TEKL,	0
                 CALL    BINDES11
                 MOVF    DCOI,0,	0
                 MOVWF   R8,	0
                 MOVF    COI,0,	0
                 MOVWF   R7,	0
                 MOVF    DEI,0,	0
                 MOVWF   R6,	0
                 MOVF    EDI,0,	0
                 MOVWF   R5,	0                
                 MOVF   SVDH,0,	0
                 MOVWF   TEKH,	0
                 MOVF    SVDL,0,0
                 MOVWF   TEKL,	0
                 CALL    BINDES11
                 MOVF    DCOI,0,	0
                 MOVWF   R4,	0
                 MOVF    COI,0,	0
                 MOVWF   R3,	0
                 MOVF    DEI,0,	0
                 MOVWF   R2,	0
                 MOVF    EDI,0,	0
                 MOVWF   R1,	0
                 RETURN
;--------- DB-2 ---------------------------------------
 ;---    -----
;-- --   28888888-------------------------------- 
DB2 

                 MOVLW   .10
                 MOVWF   R8,0  
                 MOVF    IDH_1,0,0
                 MOVWF   TEKH,0
                 MOVF    IDL_1,0,0
                 MOVWF   TEKL,0
                 CALL    BINDES11,0
                 MOVF    COI,0,0
                 MOVWF   R7,0
                 MOVF    DEI,0,0
                 MOVWF   R6,0
                 MOVF    EDI,0,0
                 MOVWF   R5,0                
                 MOVF    SPWMH,0,0
                 MOVWF   TEKH,0
                 MOVF    SPWML,0,0
                 MOVWF   TEKL,0
                 CALL    BINDES11,0
                 MOVLW   .10
                 MOVWF   R4,0              
                 MOVF    COI,0,0
                 MOVWF   R3,0
                 MOVF    DEI,0,0
                 MOVWF   R2,0
                 MOVF    EDI,0,0
                 MOVWF   R1,0
                 RETURN
;--------- DB-3--------------------------           
 ;----------E0 -  PRO-------------
 ;-- --   8888#8888------------------           
DB3  
          
             
                 MOVF    E0H,0
                 MOVWF   TEKH
                 MOVF    E0,0
                 MOVWF   TEKL
                 CALL    BINDES11
                 MOVF    DCOI,0
                 MOVWF   R8              
                 MOVF    COI,0
                 MOVWF   R7
                 MOVF    DEI,0
                 MOVWF   R6
                 MOVF    EDI,0
                 MOVWF   R5           
                 MOVF    PR0H,0
                 MOVWF   TEKH
                 MOVF    PR0,0
                 MOVWF   TEKL
       
                 CALL    BINDES11
                 MOVF    DCOI,0
                 MOVWF   R4              
                 MOVF    COI,0
                 MOVWF   R3
                 MOVF    DEI,0
                 MOVWF   R2
                 MOVF    EDI,0
                 MOVWF   R1      
                 RETURN

                      
 ;--------- DB-4--------------------------           
 ;------ 
  ;-- --   8888#8888------------------           
DB4
;				 GOTO BIN;1
                 MOVLW   .5
                 MOVWF   R8,0
                 MOVLW   .10
                 MOVWF   R7,0
                 MOVWF   R6,0
                 MOVF    TDH_1,0,0;
                 MOVWF   TEKH,0
                 MOVF    TDL_1,0,0
                 MOVWF   TEKL,0
                 CALL    BINDES11,0
                 MOVF    CCOI,0,0
                 MOVWF   R5,0              
                 MOVF    DCOI,0,0
                 MOVWF   R4,0
                 MOVF    COI,0,0
                 MOVWF   R3,0
                 MOVF    DEI,0,0
                 MOVWF   R2,0      
                 MOVF    EDI,0,0
                 MOVWF   R1,0    
                 RETURN
 
;--------------------------------------------	
                 MOVLW   .5
                 MOVWF   R8,0
                 MOVLW   .10
                 MOVWF   R7,0
                 MOVWF   R6,0
                 MOVF    TNH,0,0;   ר  SVDH
                 MOVWF   TEKH,0
                 MOVF    TNL,0,0
                 MOVWF   TEKL,0
                 CALL    BINDES11,0
                 MOVF    CCOI,0,0
                 MOVWF   R5,0              
                 MOVF    DCOI,0,0
                 MOVWF   R4,0
                 MOVF    COI,0,0
                 MOVWF   R3,0
                 MOVF    DEI,0,0
                 MOVWF   R2,0      
                 MOVF    EDI,0,0
                 MOVWF   R1,0    
                 RETURN
 ;--------- DB-5--------------------------           
 ;------Feer +PWM------
 ;-- --   8888-8888------------------           
DB5 

;				GOTO  	OTLADKA
;--------------------------------
        
                 MOVLW   .5
                 MOVWF   R8
                 MOVLW   .10
                 MOVWF   R7
                 MOVWF   R6
                MOVF    INTH,0
                MOVWF   TEKH
                MOVF    TEMP2,0
                MOVWF   TEKL 
                CALL    BINDES10
                MOVF    CCOI,0
                MOVWF   R5              
                MOVF    DCOI,0
                MOVWF   R4
                MOVF    COI,0
                MOVWF   R3
                MOVF    DEI,0
                MOVWF   R2      
                MOVF    EDI,0
                MOVWF   R1    
                RETURN
;-------------------------------------------             
OTLADKA
                 MOVF   Rkd,0                 
                 MOVWF   TEKL                 
                 CALL    BINDES10
                 MOVF    DEI,0
                 MOVWF   R8               
                 MOVF    EDI,0
                 MOVWF   R7
                 MOVLW   .10
                 MOVWF   R6    
                 MOVF   Rkp,0                 
                 MOVWF   TEKL                 
                 CALL    BINDES10
                 MOVF    DEI,0
                 MOVWF   R5               
                 MOVF    EDI,0
                 MOVWF   R4
              
                 MOVLW   .10
                 MOVWF   R3
                  
                 MOVF   Rki,0                 
                 MOVWF   TEKL                 
                 CALL    BINDES10
                 MOVF    DEI,0
                 MOVWF   R2                 
                 MOVF    EDI,0
                 MOVWF   R1
                 RETURN 
                
 ;--------- DB-6--------------------------           
;------  --------
;-- --   6--88888------------------           
DB6    
         
                 MOVLW   .6
                 MOVWF   R8
                 MOVLW   .10
                 MOVWF   R7
                 MOVWF   R6
                MOVF    PWMH,0
                MOVWF   TEKH
                MOVF    PWM,0
                MOVWF   TEKL 
                CALL    BINDES11
                MOVF    CCOI,0
                MOVWF   R5              
                MOVF    DCOI,0
                MOVWF   R4
                MOVF    COI,0
                MOVWF   R3
                MOVF    DEI,0
                MOVWF   R2      
                MOVF    EDI,0
                MOVWF   R1    
                RETURN
                
;--------- DB-7--------------------------           
;------    --------
 ;-- --   7--88888------------------           
DB7         
            

         
                 MOVLW   .7
                 MOVWF   R8
                 MOVLW   .10
                 MOVWF   R7
                 MOVWF   R6
                 MOVF    DTH ,0
     	         MOVWF   TEKH
                 MOVF    DTL ,0
                 MOVWF   TEKL
                 CALL    BINDES11
                 MOVF    CCOI,0
                 MOVWF   R5    
                 MOVF    DCOI,0
                 MOVWF   R4              
                 MOVF    COI,0
                 MOVWF   R3
                 MOVF    DEI,0
                 MOVWF   R2
                 MOVF    EDI,0
                 MOVWF   R1      
                 RETURN
                 

;****************************************************************
;
;               VIVOD
;
;****************************************************************
VIVOD

				 INCF	SL4,1,0
				 BTFSS	STATUS,Z
				 RETURN

				 INCF	SL5,1,0
				 MOVF	SL5,0,0
				 SUBLW	.60
				 BTFSS	STATUS,Z,0
				 RETURN
				 CLRF	SL5,0
 		         CLRWDT

        		CALL    OPROSKN

        		BSF		DBC,7,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC,0

        ;-----------1----------
        		MOVLW	0X0C	
        		MOVWF	RVH,0
        		MOVLW	0X01
        		MOVWF	RVL,0
        		CALL	VIV10
        ;-----------2-----------	
        		MOVLW	0X09	
        		MOVWF	RVH,0
        		MOVLW	0XFF	
        		MOVWF	RVL,0
        		CALL	VIV10
        ;------------3----------	
        		MOVLW	0X0A	
        		MOVWF	RVH,0	
        		MOVLW	0X08	
        		MOVWF	RVL,0
        		CALL	VIV10
        ;------------4----------
        		MOVLW	0X0B		
        		MOVWF	RVH,0
        		MOVLW	0X07		
        		MOVWF	RVL,0
        		CALL	VIV10
        ;-------------5---------
        		MOVLW	0X0F		
        		MOVWF	RVH,0
        		CLRF	RVL,0
        		CALL	VIV10
        ;------------6---------	
        		MOVLW	0X01	
        		MOVWF	RVH,0		
        		MOVF	R1,0,0
        		MOVWF	RVL,0
        		CALL	VIV10
        ;------------7--------
        		MOVLW	0X02		
        		MOVWF	RVH,0
        		MOVF	R2,0,0
        		MOVWF	RVL,0
        		CALL	VIV10
        ;------------8--------
        		MOVLW	0X03		
        		MOVWF	RVH,0
        		MOVF	R3,0,0
        		MOVWF	RVL,0
        		CALL	VIV10
        ;------------9-------
        		MOVLW	0X04		
        		MOVWF	RVH,0	
        		MOVF	R4,0,0
        		MOVWF	RVL,0
        		CALL	VIV10
        ;-------------------		
        ;------------10---------	
        		MOVLW	0X05	
        		MOVWF	RVH,0	
        		MOVF	R5,0,0
        		MOVWF	RVL,0
        		CALL	VIV10
        ;-------------11-------
        		MOVLW	0X06		
        		MOVWF	RVH,0
        		MOVF	R6,0
        		MOVWF	RVL,0
        		CALL	VIV10
        ;------------12--------
        		MOVLW	0X07		
        		MOVWF	RVH,0
        		MOVF	R7,0,0
        		MOVWF	RVL,0
        		CALL	VIV10
        ;------------13-------
        		MOVLW	0X08		
        		MOVWF	RVH,0	
        		MOVF	R8,0,0
        		MOVWF	RVL,0
        		CALL	VIV10
    ;-----------  --------

        		BSF		DBC,7,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC,0                        
        		BCF		DBC,7,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC,0        
        		BCF		DBC,2,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC,0        
        		BSF		DBC,2,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC,0        
        		BSF		DBC,7,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC,0        
      ;--------------------------
      	    	MOVLW	.8
	        	MOVWF	CIKL,0
                CLRF    RVL,0
VM3                              	        	 
                BCF     STATUS,0,0
                BTFSC   PORTC,5,0
                BSF     STATUS,0,0
        		BCF		DBC,2,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC,0        
        		BSF		DBC,2,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC,0                                   
                RLCF     RVL,1,0               
                DECFSZ  CIKL,1,0
                GOTO    VM3
                COMF    RVL,0,0
                MOVWF   NP1,0
;------------------1 --------------------------
      	    	MOVLW	.8
	        	MOVWF	CIKL
                CLRF    RVL
VM4                              	        	 
                BCF     STATUS,0
                BTFSC   PORTC,5
                BSF     STATUS,0
        		BCF		DBC,2
        		MOVF	DBC,0
        		MOVWF	PORTC        
        		BSF		DBC,2
        		MOVF	DBC,0
        		MOVWF	PORTC                                   
                RLCF     RVL,1               
                DECFSZ  CIKL,1
                GOTO    VM4
                COMF    RVL,0
                MOVWF   TEMPV

;				 ANDLW	 0X0F
;                 MOVWF   Rkp
;				 SWAPF	 TEMPV,0
;				 ANDLW	 0X0F
;                 MOVWF   Rkd

;------------------2 --------------------------
      	    	MOVLW	.8
	        	MOVWF	CIKL
                CLRF    RVL
VM5                              	        	 
                BCF     STATUS,0
                BTFSC   PORTC,5
                BSF     STATUS,0
        		BCF		DBC,2
        		MOVF	DBC,0
        		MOVWF	PORTC        
        		BSF		DBC,2
        		MOVF	DBC,0
        		MOVWF	PORTC                                   
                RLCF     RVL,1               
                DECFSZ  CIKL,1
                GOTO    VM5
                COMF    RVL,0
                MOVWF   TEMPV
				 ANDLW	 0X0F
;                 MOVWF   Rko
;				 SWAPF	 TEMPV,0
;				 ANDLW	 0X0F
;                 MOVWF   Rki     
;------------------3 --------------------------
      	    	MOVLW	.8
	        	MOVWF	CIKL,0
                CLRF    RVL,0
VM6                              	        	 
                BCF     STATUS,0,0
                BTFSC   PORTC,5,0
                BSF     STATUS,0,0
        		BCF		DBC,2,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC ,0       
        		BSF		DBC,2,0
        		MOVF	DBC,0,0
        		MOVWF	PORTC,0                                   
                RLCF     RVL,1,0               
                DECFSZ  CIKL,1,0
                GOTO    VM6
                COMF    RVL,0,0
        		RETURN		
;-------------------------------------


VIV10

;----------------------------	


VM2	
				BCF		DBC,1,0
				MOVF	DBC,0,0
				MOVWF	PORTC,0
;----------------1--------------
				MOVLW	.8
				MOVWF	CIKL,0
VM1
				RLCF	RVH,1,0
				CALL	STROB,0
				DECFSZ	CIKL,1,0
				BRA	VM1
;----------------2---------------
				MOVLW	.8
				MOVWF	CIKL,0
VM11
				RLCF	RVL,1,0
				CALL	STROB,0
				DECFSZ	CIKL,1,0
				BRA		VM11
				BSF		DBC,1,0
				MOVF	DBC,0,0
				MOVWF	PORTC,0
				RETURN		

;-------STROB------------	
STROB
				BTFSC	STATUS,0;   0/1 -	
				BSF		DBC,6,0
				MOVF	DBC,0,0
				MOVWF	PORTC,0
		
				BSF		DBC,2,0
				MOVF	DBC,0,0
				MOVWF	PORTC,0
				NOP
				BCF		DBC,2,0
				MOVF	DBC,0,0
				MOVWF	PORTC,0
		
				BCF		DBC,6,0
				MOVF	DBC,0,0
				MOVWF	PORTC,0
				RETURN
YST
 
;************16-2/10**************************************************************************
BINDES10
                 CLRF    TEKH,0
BINDES11

                 MOVLW   .16
                 MOVWF   COU,0
BIDE
                 BCF     STATUS,0
                 RLCF             TEKL,1,0
                 RLCF             TEKH,1,0
                 RLCF             EDA,1,0
                 RLCF             DEA,1,0
                 RLCF             COA,1,0
                 DECFSZ  COU,1,0
                 GOTO    RASDES          
                 GOTO    MESTO
RASDES 
                 LFSR	FSR1,	EDA
                 CALL    BCD
                 LFSR	FSR1,	DEA
                 CALL    BCD     
                 LFSR	FSR1,	COA
                 CALL    BCD             
                 GOTO    BIDE    

BCD
                 MOVLW   0X03
                 ADDWF   INDF1,0,0
                 MOVWF   TEMP,0
                 BTFSC   TEMP,3
                 MOVWF   INDF1,0               
                 MOVLW   0X30
                 ADDWF   INDF1,0,0
                 MOVWF   TEMP,0
                 BTFSC   TEMP,7
                 MOVWF   INDF1
                 RETURN
;--------------------------------------------
MESTO
                 MOVLW   0X0F
                 ANDWF   COA,0
                 MOVWF   CCOI                                 
                 MOVLW   0XF0                            
                 ANDWF   DEA,0
                 MOVWF   DCOI,0
                 SWAPF   DCOI,1,0
                 MOVLW   0X0F
                 ANDWF   DEA,0,0
                 MOVWF   COI,0
                 MOVLW   0XF0                            
                 ANDWF   EDA,0,0
                 MOVWF   DEI,0
                 SWAPF   DEI,1
                 MOVLW   0X0F
                 ANDWF   EDA,0,0
                 MOVWF   EDI,0
                 CLRF    EDA,0
                 CLRF    DEA,0
                 CLRF    COA,0
                 RETURN
;------------------------------------------------
                      
;-----------------------------------------          
ZAD10
         MOVLW   .10
         MOVWF   ZAD,0
ZA1
         CALL    ZAD2
         DECFSZ  ZAD,1,0        
         BRA    ZA1
        RETURN

;-----------------------------------------          
ZAD20
         MOVLW   .20
         MOVWF   ZAD,0
ZA2
         CALL    ZAD2,0
         DECFSZ  ZAD,1,0        
         BRA    ZA2
        RETURN
;-----------------------------------------     
ZAD2
         NOP     
         NOP
         NOP
         NOP 
         NOP
         NOP 
         NOP
         NOP
         NOP
         NOP
         RETURN 

;------------------ ----------------------------
C0NST_DV
;--------------  2000  /--OX00C8-SVDH,L-----------
				 MOVLW	0X01;		
				 SUBWF	SVDH, 0,0
				 MOVWF	R1,0
		
				 MOVLW	0X01	;	
				 SUBWF	SVDL, 0,0
				 MOVWF	R2,0
				 BTFSS	STATUS,C,0
				 DECF	R1,1,0
		
		         BTFSC  R1,7,0;    .  
				 GOTO 	 DLDV1 
;--------------  4000  /--0X0190-SVDH,L-----------
				 MOVLW	0X01;		
				 SUBWF	SVDH, 0,0
				 MOVWF	R1,0
		
				 MOVLW	0X90	;	
				 SUBWF	SVDL, 0,0
				 MOVWF	R2,0
				 BTFSS	STATUS,C,0
				 DECF	R1,1,0
		
		         BTFSC  R1,7,0;    .  
				 GOTO 	 DLDV2 

				 GOTO 	 DLDV3 
				 RETURN
;----------------  2.000 /--------------------------------
DLDV1
                MOVLW   .6
                MOVWF   Rkd,0

                MOVLW   .8
                MOVWF   Rkp,0

                MOVLW   .3
                MOVWF   Rki,0

                RETURN
;----------------  4.000 /--------------------------------
DLDV2
               MOVLW   .5
                MOVWF   Rkd,0

                MOVLW   .5
                MOVWF   Rkp,0

                MOVLW   .2
                MOVWF   Rki,0

                RETURN
;----------------  5.000 /--------------------------------
DLDV3
               MOVLW   .5
                MOVWF   Rkd,0

                MOVLW   .4
                MOVWF   Rkp,0

                MOVLW   .2
                MOVWF   Rki,0

                RETURN
;------------------------------------------------------------------
DT11
	        	CLRF    E0,0
	            CLRF    E1,0

	            CLRF    E0H,0
	            CLRF    E1H,0

	            CLRF	PWMH,0
	        	CLRF	PWM,0
	
	            CLRF	PR0H,0
	        	CLRF	PR0,0
	
	        	CLRF    INTH,0
	        	CLRF    INT,0;  	
				CLRF	BIT_AVR1,0        
				CLRF	BIT_AVR2,0        
				CLRF	BIT_AVR3,0        
				CLRF	SYM_AVR,0 
				CLRF	TEMPA,0; 	
				CLRF	TEMPB,0
				CLRF	TEMPC,0
	        	CLRF    E0,0
	            CLRF    E1,0
	            CLRF    E0H,0
	            CLRF    E1H,0
				MOVLW	0X30
	            MOVWF   DTH,0 
	            CLRF    DTL,0 
				BCF		FBEEP	
	           	RETURN    	

 ;------------------------------
IMP1
			    BSF 	   PORTC,1,0	
				NOP
				NOP
				NOP
				NOP
				NOP
				NOP
				NOP
				NOP
				NOP
				NOP
				NOP
				NOP
				NOP
			    BCF 	   PORTC,1,0
			  RETURN
;************************************************************************************* 
;------------------------------------------------
; /     unsigned fixed point  32 / 16 = 32.16   < + >
;  INPUT:   accb0,accb1,accb2,accb3 / bccb0,bccb1  (H,L)
;  UZE :    temb0,temb1,temp
;  REZALT:  accb0,accb1,accb2,accb3.temp0,temp1 (lsb)
;           ( bccb1,bccb0 = const ) temp0,temp1=???
;  XXXXXX / 00FFFFFF, 00000000 / XXXX = 00000000
;        (  line ;   Tclk)
;------------------------------------------------
DIV1
		clrf  temb0,A
        clrf  temb1,A
udiv3216l:
		clrf  temp,A
        rlcf   accb0,W,A
        rlcf   temb1,F,A
        movf  bccb1,W,A
        subwf temb1,F,A
        movf  bccb0,W,A           ;??????????????????
        btfss STATUS,C,A
        incfsz bccb0,W,A
        subwf temb0,F,A
        clrf  WREG,A
        btfss STATUS,C,A
        movlw 0x01
        subwf temp,F,A
        rlcf   accb0,F,A         ; !
        movlw 0x07
        movwf loopcount,A
loopu3216a:
		rlcf   accb0,W,A
        rlcf   temb1,F,A
        rlcf   temb0,F,A
        rlcf   temp,F,A
        movf  bccb1,W,A
        btfss accb0,0,A
        bra   uadd26la
        subwf temb1,F,A
        movf  bccb0,W,A
        btfss STATUS,C,A
        incfsz bccb0,W,A
        subwf temb0,F,A
        clrf  WREG,A
        btfss STATUS,C,A
        movlw 0x01
        subwf temp,F,A
        bra   uok26la
uadd26la:
		addwf temb1,F,A
        movf  bccb0,W,A
        btfsc STATUS,C,A
        incfsz bccb0,W,A
        addwf temb0,F,A
        clrf  WREG,A
        btfsc STATUS,C,A
        movlw 0x01
        addwf temp,F,A
uok26la:
		rlcf   accb0,F,A
        decfsz loopcount,F,A
        bra   loopu3216a
        rlcf  accb1,W,A
        rlcf  temb1,F,A
        rlcf  temb0,F,A
        rlcf  temp,F,A
        movf  bccb1,W,A
        btfss accb0,0,A
        bra   uadd26l8
        subwf temb1,F,A
        movf  bccb0,W,A
        btfss STATUS,C,A
        incfsz bccb0,W,A
        subwf temb0,F,A
        clrf  WREG,A
        btfss STATUS,C,A
        movlw 0x01
        subwf temp,F,A
        bra   uok26l8
uadd26l8:
		addwf temb1,F,A
        movf  bccb0,W,A
        btfsc STATUS,C,A
        incfsz bccb0,W,A
        addwf temb0,F,A
        clrf  WREG,A
        btfsc STATUS,C,A
        movlw 0x01
        addwf temp,F,A
uok26l8:
		rlcf   accb1,F,A
        movlw 0x07
        movwf loopcount,A
loopu3216b:
		rlcf   accb1,W,A
        rlcf   temb1,F,A
        rlcf   temb0,F,A
        rlcf   temp,F,A
        movf  bccb1,W,A
        btfss accb1,0,A
        bra   uadd26lb
        subwf temb1,F,A
        movf  bccb0,W,A
        btfss STATUS,C,A
        incfsz bccb0,W,A
        subwf temb0,F,A
        clrf  WREG,A
        btfss STATUS,C,A
        movlw 0x01
        subwf temp,F,A
        bra   uok26lb
uadd26lb:
		addwf temb1,F,A
        movf  bccb0,W,A
        btfsc STATUS,C,A
        incfsz bccb0,W,A
        addwf temb0,F,A
        clrf  WREG,A
        btfsc STATUS,C,A
        movlw 0x01
        addwf temp,F,A
uok26lb:
		rlcf   accb1,F,A
        decfsz loopcount,F,A
        bra    loopu3216b
        rlcf   accb2,W,A
        rlcf   temb1,F,A
        rlcf   temb0,F,A
        rlcf   temp,F,A
        movf  bccb1,W,A
        btfss accb1,0,A
        bra   uadd26l16
        subwf temb1,F,A
        movf  bccb0,W,A
        btfss STATUS,C,A
        incfsz bccb0,W,A
        subwf temb0,F,A
        clrf  WREG,A
        btfss STATUS,C,A
        movlw 0x01
        subwf temp,F,A
        bra   uok26l16
uadd26l16:
		addwf temb1,F,A
        movf  bccb0,W,A
        btfsc STATUS,C,A
        incfsz bccb0,W,A
        addwf temb0,F,A
        clrf  WREG,A
        btfsc STATUS,C,A
        movlw 0x01
        addwf temp,F,A
uok26l16:
		rlcf   accb2,F,A
        movlw 0x07
        movwf loopcount,A
loopu3216c:
		rlcf   accb2,W,A
        rlcf   temb1,F,A
        rlcf   temb0,F,A
        rlcf   temp,F,A
        movf   bccb1,W,A
        btfss  accb2,0,A
        bra    uadd26lc
        subwf  temb1,F,A
        movf   bccb0,W,A
        btfss  STATUS,C,A
        incfsz bccb0,W,A
        subwf  temb0,F,A
        movlw  0x00
        btfss STATUS,C,A
        movlw 0x01
        subwf temp,F,A
        bra   uok26lc
uadd26lc:
		addwf temb1,F,A
        movf  bccb0,W,A
        btfsc STATUS,C,A
        incfsz bccb0,W,A
        addwf temb0,F,A
        clrf  WREG,A
        btfsc STATUS,C,A
        movlw 0x01
        addwf temp,F,A
uok26lc:
		rlcf   accb2,F,A
        decfsz loopcount,F,A
        bra   loopu3216c
        rlcf   accb3,W,A
        rlcf   temb1,F,A
        rlcf   temb0,F,A
        rlcf   temp,F,A
        movf  bccb1,W,A
        btfss accb2,0,A
        bra   uadd26l24
        subwf temb1,F,A
        movf  bccb0,W,A
        btfss STATUS,C,A
        incfsz bccb0,W,A
        subwf temb0,F,A
        clrf  WREG,A
        btfss STATUS,C,A
        movlw 0x01
        subwf temp,F,A
        goto  uok26l24
uadd26l24:
		addwf temb1,F,A
        movf  bccb0,W,A
        btfsc STATUS,C,A
        incfsz bccb0,W,A
        addwf temb0,F,A
        clrf  WREG,A
        btfsc STATUS,C,A
        movlw 0x01
        addwf temp,F,A
uok26l24:
		rlcf   accb3,F,A
        movlw 0x07
        movwf loopcount,A
loopu3216d:
		rlcf   accb3,W,A
        rlcf   temb1,F,A
        rlcf   temb0,F,A
        rlcf   temp,F,A
        movf  bccb1,W,A
        btfss accb3,0,A
        bra   uadd26ld
        subwf temb1,F,A
        movf  bccb0,W,A
        btfss STATUS,C,A
        incfsz bccb0,W,A
        subwf temb0,F,A
        clrf  WREG,A
        btfss STATUS,C,A
        movlw 0x01
        subwf temp,F,A
        bra   uok26ld
uadd26ld:
		addwf temb1,F,A
        movf  bccb0,W,A
        btfsc STATUS,C,A
        incfsz bccb0,W,A
        addwf temb0,F,A
        clrf  WREG,A
        btfsc STATUS,C,A
        movlw 0x01
        addwf temp,F,A
uok26ld:
		rlcf   accb3,F,A
        decfsz loopcount,F,A
        bra   loopu3216d
        btfss accb3,0,A
        bra   uok26l
        movf  bccb1,W,A
        addwf temb1,F,A
        movf  bccb0,W,A
        btfsc STATUS,C,A
        incfsz bccb0,W,A
        addwf temb0,F,A
uok26l:
        retlw 0x00
                 END

;*****************************************************		

                     		

	END

